@@ -82,6 +82,15 @@ gcr_data_error_get_domain (void)
 	return domain;
 }
 
+GQuark
+gcr_error_get_domain (void)
+{
+	static GQuark domain = 0;
+	if (domain == 0)
+		domain = g_quark_from_static_string ("gcr-error");
+	return domain;
+}
+
 /* -----------------------------------------------------------------------------
  * MEMORY
  */
